@@ -31,13 +31,13 @@
 
 /* clutter-actor.h */
 
-#include <glib-object.h>
 #include <pango/pango.h>
+#include <atk/atk.h>
+
+#include <cogl/cogl.h>
 
-#include <clutter/clutter-color.h>
 #include <clutter/clutter-types.h>
 #include <clutter/clutter-event.h>
-#include <clutter/clutter-shader.h>
 
 G_BEGIN_DECLS
 
@@ -134,25 +134,6 @@ typedef enum
   CLUTTER_ABSOLUTE_ORIGIN_CHANGED = 1 << 1
 } ClutterAllocationFlags;
 
-/**
- * ClutterRedrawFlags:
- * @CLUTTER_REDRAW_CLIPPED_TO_BOX: Tells clutter the redraw is clipped
- *   to a given clip box in actor coordinates.
- * @CLUTTER_REDRAW_CLIPPED_TO_ALLOCATION: Tells clutter the maximum
- *   extents of what needs to be redrawn lies within the actors
- *   current allocation.
- *
- * Flags passed to the clutter_actor_queue_redraw_with_clip ()
- * function
- *
- * Since: 1.2
- */
-typedef enum
-{
-  CLUTTER_REDRAW_CLIPPED_TO_BOX         = 0,
-  CLUTTER_REDRAW_CLIPPED_TO_ALLOCATION  = 1 << 1
-} ClutterRedrawFlags;
-
 /**
  * ClutterActor:
  * @flags: #ClutterActorFlags
@@ -192,9 +173,11 @@ struct _ClutterActor
  * @unrealize: virtual function, used to deallocate resources allocated
  *   in ::realize; it should chain up to the parent's implementation
  * @map: virtual function for containers and composite actors, to
- *   map their children; it must chain up to the parent's implementation
+ *   map their children; it must chain up to the parent's implementation.
+ *   Overriding this function is optional.
  * @unmap: virtual function for containers and composite actors, to
- *   unmap their children; it must chain up to the parent's implementation
+ *   unmap their children; it must chain up to the parent's implementation.
+ *   Overriding this function is optional.
  * @paint: virtual function, used to paint the actor
  * @get_preferred_width: virtual function, used when querying the minimum
  *   and natural widths of an actor for a given height; it is used by
@@ -225,9 +208,13 @@ struct _ClutterActor
  * @enter_event: signal class closure for #ClutterActor::enter-event
  * @leave_event: signal class closure for #ClutterActor::leave-event
  * @captured_event: signal class closure for #ClutterActor::captured-event
- * @key_focus_in: signal class closure for #ClutterActor::focus-in
- * @key_focus_out: signal class closure for #ClutterActor::focus-out
+ * @key_focus_in: signal class closure for #ClutterActor::key-focus-in
+ * @key_focus_out: signal class closure for #ClutterActor::key-focus-out
  * @queue_relayout: class handler for #ClutterActor::queue-relayout
+ * @get_accessible: virtual function, returns the accessible object that
+ *   describes the actor to an assistive technology.
+ * @get_paint_volume: virtual function, for sub-classes to define their
+ *   #ClutterPaintVolume
  *
  * Base class for actors.
  */
@@ -237,19 +224,19 @@ struct _ClutterActorClass
   GInitiallyUnownedClass parent_class;
 
   /*< public >*/
-  void (* show)                 (ClutterActor          *actor);
-  void (* show_all)             (ClutterActor          *actor);
-  void (* hide)                 (ClutterActor          *actor);
-  void (* hide_all)             (ClutterActor          *actor);
-  void (* realize)              (ClutterActor          *actor);
-  void (* unrealize)            (ClutterActor          *actor);
-  void (* map)                  (ClutterActor          *actor);
-  void (* unmap)                (ClutterActor          *actor);
-  void (* paint)                (ClutterActor          *actor);
+  void (* show)                 (ClutterActor          *self);
+  void (* show_all)             (ClutterActor          *self);
+  void (* hide)                 (ClutterActor          *self);
+  void (* hide_all)             (ClutterActor          *self);
+  void (* realize)              (ClutterActor          *self);
+  void (* unrealize)            (ClutterActor          *self);
+  void (* map)                  (ClutterActor          *self);
+  void (* unmap)                (ClutterActor          *self);
+  void (* paint)                (ClutterActor          *self);
   void (* parent_set)           (ClutterActor          *actor,
                                  ClutterActor          *old_parent);
 
-  void (* destroy)              (ClutterActor          *actor);
+  void (* destroy)              (ClutterActor          *self);
   void (* pick)                 (ClutterActor          *actor,
                                  const ClutterColor    *color);
 
@@ -257,15 +244,15 @@ struct _ClutterActorClass
                                  ClutterActor          *leaf_that_queued);
 
   /* size negotiation */
-  void (* get_preferred_width)  (ClutterActor           *actor,
+  void (* get_preferred_width)  (ClutterActor           *self,
                                  gfloat                  for_height,
                                  gfloat                 *min_width_p,
                                  gfloat                 *natural_width_p);
-  void (* get_preferred_height) (ClutterActor           *actor,
+  void (* get_preferred_height) (ClutterActor           *self,
                                  gfloat                  for_width,
                                  gfloat                 *min_height_p,
                                  gfloat                 *natural_height_p);
-  void (* allocate)             (ClutterActor           *actor,
+  void (* allocate)             (ClutterActor           *self,
                                  const ClutterActorBox  *box,
                                  ClutterAllocationFlags  flags);
 
@@ -297,11 +284,17 @@ struct _ClutterActorClass
   void     (* key_focus_in)         (ClutterActor         *actor);
   void     (* key_focus_out)        (ClutterActor         *actor);
 
-  void     (* queue_relayout)       (ClutterActor         *actor);
+  void     (* queue_relayout)       (ClutterActor         *self);
+
+  /* accessibility support */
+  AtkObject * (* get_accessible)    (ClutterActor         *self);
+
+  gboolean    (* get_paint_volume)  (ClutterActor         *actor,
+                                     ClutterPaintVolume   *volume);
 
   /*< private >*/
   /* padding for future expansion */
-  gpointer _padding_dummy[31];
+  gpointer _padding_dummy[29];
 };
 
 GType                 clutter_actor_get_type                  (void) G_GNUC_CONST;
@@ -354,6 +347,13 @@ void                  clutter_actor_allocate_available_size   (ClutterActor
                                                                gfloat                 available_width,
                                                                gfloat                 available_height,
                                                                ClutterAllocationFlags flags);
+void                  clutter_actor_allocate_align_fill       (ClutterActor          *self,
+                                                               const ClutterActorBox *box,
+                                                               gdouble                x_align,
+                                                               gdouble                y_align,
+                                                               gboolean               x_fill,
+                                                               gboolean               y_fill,
+                                                               ClutterAllocationFlags flags);
 void                  clutter_actor_get_allocation_box        (ClutterActor          *self,
                                                                ClutterActorBox       *box);
 void                  clutter_actor_get_allocation_geometry   (ClutterActor          *self,
@@ -441,6 +441,9 @@ void                  clutter_actor_get_clip                  (ClutterActor
                                                                gfloat                *yoff,
                                                                gfloat                *width,
                                                                gfloat                *height);
+void                  clutter_actor_set_clip_to_allocation    (ClutterActor          *self,
+                                                               gboolean               clip_set);
+gboolean              clutter_actor_get_clip_to_allocation    (ClutterActor          *self);
 
 void                  clutter_actor_set_parent                (ClutterActor          *self,
                                                                ClutterActor          *parent);
@@ -448,6 +451,8 @@ ClutterActor *        clutter_actor_get_parent                (ClutterActor
 void                  clutter_actor_reparent                  (ClutterActor          *self,
                                                                ClutterActor          *new_parent);
 void                  clutter_actor_unparent                  (ClutterActor          *self);
+gboolean              clutter_actor_contains                  (ClutterActor          *self,
+							       ClutterActor          *descendant);
 ClutterActor*         clutter_actor_get_stage                 (ClutterActor          *actor);
 
 void                  clutter_actor_raise                     (ClutterActor          *self,
@@ -492,7 +497,7 @@ gboolean              clutter_actor_event                     (ClutterActor
                                                                ClutterEvent          *event,
                                                                gboolean               capture);
 
-ClutterActor *        clutter_get_actor_by_gid                (guint32                id);
+ClutterActor *        clutter_get_actor_by_gid                (guint32                id_);
 
 gboolean              clutter_actor_set_shader                (ClutterActor          *self,
                                                                ClutterShader         *shader);
@@ -562,6 +567,19 @@ ClutterTextDirection clutter_actor_get_text_direction (ClutterActor         *sel
 void                 clutter_actor_push_internal      (ClutterActor         *self);
 void                 clutter_actor_pop_internal       (ClutterActor         *self);
 
+gboolean             clutter_actor_has_allocation     (ClutterActor         *self);
+
+AtkObject *          clutter_actor_get_accessible     (ClutterActor         *self);
+
+gboolean             clutter_actor_has_key_focus      (ClutterActor         *self);
+
+const ClutterPaintVolume  *clutter_actor_get_paint_volume             (ClutterActor         *self);
+const ClutterPaintVolume  *clutter_actor_get_transformed_paint_volume (ClutterActor *self,
+                                                                       ClutterActor *relative_to_ancestor);
+
+gboolean             clutter_actor_get_paint_box      (ClutterActor         *self,
+                                                       ClutterActorBox      *box);
+
 G_END_DECLS
 
 #endif /* __CLUTTER_ACTOR_H__ */
