@@ -18,9 +18,9 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * License along with this library. If not, see <http://www.gnu.org/licenses/>.
+ *
+ *
  */
 
 /**
@@ -241,7 +241,7 @@ clutter_score_class_init (ClutterScoreClass *klass)
 		  G_SIGNAL_RUN_LAST,
 		  G_STRUCT_OFFSET (ClutterScoreClass, timeline_started),
 		  NULL, NULL,
-		  clutter_marshal_VOID__OBJECT,
+		  _clutter_marshal_VOID__OBJECT,
 		  G_TYPE_NONE,
 		  1, CLUTTER_TYPE_TIMELINE);
   /**
@@ -260,7 +260,7 @@ clutter_score_class_init (ClutterScoreClass *klass)
                  G_SIGNAL_RUN_LAST,
                  G_STRUCT_OFFSET (ClutterScoreClass, timeline_completed),
                  NULL, NULL,
-                 clutter_marshal_VOID__OBJECT,
+                 _clutter_marshal_VOID__OBJECT,
                  G_TYPE_NONE, 1,
                  CLUTTER_TYPE_TIMELINE);
   /**
@@ -277,7 +277,7 @@ clutter_score_class_init (ClutterScoreClass *klass)
 		  G_SIGNAL_RUN_LAST,
 		  G_STRUCT_OFFSET (ClutterScoreClass, completed),
 		  NULL, NULL,
-		  clutter_marshal_VOID__VOID,
+		  _clutter_marshal_VOID__VOID,
 		  G_TYPE_NONE, 0);
   /**
    * ClutterScore::started:
@@ -293,7 +293,7 @@ clutter_score_class_init (ClutterScoreClass *klass)
 		  G_SIGNAL_RUN_LAST,
 		  G_STRUCT_OFFSET (ClutterScoreClass, started),
 		  NULL, NULL,
-		  clutter_marshal_VOID__VOID,
+		  _clutter_marshal_VOID__VOID,
 		  G_TYPE_NONE, 0);
   /**
    * ClutterScore::paused:
@@ -310,7 +310,7 @@ clutter_score_class_init (ClutterScoreClass *klass)
 		  G_SIGNAL_RUN_LAST,
 		  G_STRUCT_OFFSET (ClutterScoreClass, paused),
 		  NULL, NULL,
-		  clutter_marshal_VOID__VOID,
+		  _clutter_marshal_VOID__VOID,
 		  G_TYPE_NONE, 0);
 }
 
@@ -555,14 +555,14 @@ find_entry_by_timeline (ClutterScore    *score,
 
 static GNode *
 find_entry_by_id (ClutterScore *score,
-                  gulong        id)
+                  gulong        id_)
 {
   ClutterScorePrivate *priv = score->priv;
   TraverseClosure closure;
 
   closure.action = FIND_BY_ID;
   closure.score = score;
-  closure.d.id = id;
+  closure.d.id = id_;
   closure.result = NULL;
 
   g_node_traverse (priv->root,
@@ -860,7 +860,7 @@ clutter_score_clear (ClutterScore *score)
 /**
  * clutter_score_append:
  * @score: a #ClutterScore
- * @parent: a #ClutterTimeline in the score, or %NULL
+ * @parent: (allow-none): a #ClutterTimeline in the score, or %NULL
  * @timeline: a #ClutterTimeline
  *
  * Appends a timeline to another one existing in the score; the newly
@@ -990,6 +990,7 @@ clutter_score_append_at_marker (ClutterScore    *score,
   entry->marker = g_strdup (marker_name);
   entry->id = priv->last_id;
   entry->score = score;
+  entry->complete_id = 0;
 
   marker_reached_signal = g_strdup_printf ("marker-reached::%s", marker_name);
   entry->marker_id = g_signal_connect (entry->parent,
@@ -1009,7 +1010,7 @@ clutter_score_append_at_marker (ClutterScore    *score,
 /**
  * clutter_score_remove:
  * @score: a #ClutterScore
- * @id: the id of the timeline to remove
+ * @id_: the id of the timeline to remove
  *
  * Removes the #ClutterTimeline with the given id inside @score. If
  * the timeline has other timelines attached to it, those are removed
@@ -1019,19 +1020,19 @@ clutter_score_append_at_marker (ClutterScore    *score,
  */
 void
 clutter_score_remove (ClutterScore *score,
-                      gulong        id)
+                      gulong        id_)
 {
   ClutterScorePrivate *priv;
   TraverseClosure closure;
 
   g_return_if_fail (CLUTTER_IS_SCORE (score));
-  g_return_if_fail (id > 0);
+  g_return_if_fail (id_ > 0);
 
   priv = score->priv;
 
   closure.action = REMOVE_BY_ID;
   closure.score = score;
-  closure.d.id = id;
+  closure.d.id = id_;
   closure.result = NULL;
 
   g_node_traverse (priv->root,
@@ -1074,9 +1075,9 @@ clutter_score_remove_all (ClutterScore *score)
 /**
  * clutter_score_get_timeline:
  * @score: a #ClutterScore
- * @id: the id of the timeline
+ * @id_: the id of the timeline
  *
- * Retrieves the #ClutterTimeline for @id inside @score.
+ * Retrieves the #ClutterTimeline for @id_ inside @score.
  *
  * Return value: (transfer none): the requested timeline, or %NULL. This
  *   function does not increase the reference count on the returned
@@ -1086,15 +1087,15 @@ clutter_score_remove_all (ClutterScore *score)
  */
 ClutterTimeline *
 clutter_score_get_timeline (ClutterScore *score,
-                            gulong        id)
+                            gulong        id_)
 {
   GNode *node;
   ClutterScoreEntry *entry;
 
   g_return_val_if_fail (CLUTTER_IS_SCORE (score), NULL);
-  g_return_val_if_fail (id > 0, NULL);
+  g_return_val_if_fail (id_ > 0, NULL);
 
-  node = find_entry_by_id (score, id);
+  node = find_entry_by_id (score, id_);
   if (G_UNLIKELY (!node))
     return NULL;
 
@@ -1109,10 +1110,10 @@ clutter_score_get_timeline (ClutterScore *score,
  *
  * Retrieves a list of all the #ClutterTimelines managed by @score.
  *
- * Return value: (transfer container) (element-type ClutterTimeline): a #GSList
- *   containing all the timelines in the score. This function does not increase
- *   the reference count of the returned timelines. Use g_slist_free() on the
- *   returned list to deallocate its resources.
+ * Return value: (transfer container) (element-type Clutter.Timeline): a
+ *   #GSList containing all the timelines in the score. This function does
+ *   not increase the reference count of the returned timelines. Use
+ *   g_slist_free() on the returned list to deallocate its resources.
  *
  * Since: 0.6
  */
